package com.iamberry.wechat.service.integral;

import com.github.pagehelper.PageHelper;
import com.iamberry.wechat.core.entity.admin.ShopSystemRule;
import com.iamberry.wechat.core.entity.integral.*;
import com.iamberry.wechat.core.entity.member.Member;
import com.iamberry.wechat.core.entity.page.PageRequest;
import com.iamberry.wechat.core.entity.page.PagedResult;
import com.iamberry.wechat.face.admin.SystemService;
import com.iamberry.wechat.face.integral.UseIntegralService;
import com.iamberry.wechat.service.mapper.MemberMapper;
import com.iamberry.wechat.service.mapper.UseIntegralMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import util.PageUtil;

import java.beans.Transient;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class UseIntegralServiceImpl implements UseIntegralService {

    private Logger logger = LoggerFactory.getLogger(UseIntegralServiceImpl.class);

    @Autowired
    private UseIntegralMapper useIntegralMapper;

    @Autowired
    private MemberMapper memberMapper;
    @Autowired
    private UseIntegralService useIntegralService;

    @Autowired
    private SystemService systemService;

    /**
     * 获取会员信息.会员等级名称
     * @param openId
     * @return
     */
    @Override
    public MemberIntegral getMemberInfoAndRankName(String openId) {
        return useIntegralMapper.getMemberInfoAndRankName(openId);
    }

    /**
     * 获得的总积分数
     * @param userOpenId
     * @return
     */
    @Override
    public Integer getGainIntegralCount(String userOpenId) {
        return useIntegralMapper.getGainIntegralCount(userOpenId);
    }

    /**
     * 使用的总积分数
     * @param openid
     * @return
     */
    @Override
    public Integer getUseIntegralCount(String openid) {
        return useIntegralMapper.getUseIntegralCount(openid);
    }

    /**
     * 待入账的总积分数
     * @param userOpenId
     * @return
     */
    @Override
    public Integer getStayIntegralCount(String userOpenId) {
        return useIntegralMapper.getStayIntegralCount(userOpenId);
    }

    /**
     * 全部积分记录
     * @param useIntegral
     * @return
     */
    @Override
    public List<UseIntegral> listIntegralInfo(UseIntegral useIntegral) {
        return useIntegralMapper.listIntegralInfo(useIntegral);
    }

    @Override
    public List<IntegralConfig> listIntegralConfig(IntegralConfig integralConfig) {
        return useIntegralMapper.listIntegralConfig(integralConfig);
    }

    /**
     * 查询会员等级信息
     * @return
     */
    @Override
    public List<RankRule> getRankRule() {
        return useIntegralMapper.getRankRule();
    }

    /**
     * 查询会员等级信息
     * @param  id
     * @return  rankRule
     */
    @Override
    public  RankRule  getRankRuleById(Integer  id){
        return  useIntegralMapper.getRankRuleById(id);
    }

    /**
     * 查询待入账积分的集合
     * @return
     */
    @Override
    public List<StayIntegral>  listStayIntegral(StayIntegral stayIntegral){
        return useIntegralMapper.listStayIntegral(stayIntegral);
    }

    @Override
    public PagedResult<UseIntegral> listUseIntegral(PageRequest<UseIntegral> pageRequest) {
        PageHelper.startPage(pageRequest.getPageNO(), pageRequest.getPageSize(), pageRequest.isPageTotal());
        List<UseIntegral> detedctList = useIntegralMapper.listUseIntegral(pageRequest.getData());
        return PageUtil.getPage(detedctList);
    }

    @Override
    public Integer listUseIntegralCount(UseIntegral useIntegral) {
        return useIntegralMapper.listUseIntegralCount(useIntegral);
    }

    @Override
    public PagedResult<StayIntegral> listAdminStayIntegral(PageRequest<StayIntegral> pageRequest) {
        PageHelper.startPage(pageRequest.getPageNO(), pageRequest.getPageSize(), pageRequest.isPageTotal());
        List<StayIntegral> detedctList = useIntegralMapper.listAdminStayIntegral(pageRequest.getData());
        return PageUtil.getPage(detedctList);
    }

    @Override
    public Integer listAdminStayIntegralCount(StayIntegral stayIntegral) {
        return useIntegralMapper.listAdminStayIntegralCount(stayIntegral);
    }

    @Override
    public Integer updatestayIntegralStatus(StayIntegral stayIntegral) {
        return useIntegralMapper.updatestayIntegralStatus(stayIntegral);
    }

    @Override
    public boolean updateIntegralStayToAlready() {
        StayIntegral stayIntegral = new StayIntegral();
        stayIntegral.setStayStatus(1);
        stayIntegral.setStayRecordedTime(new Date());
        /*获取所有的待入账积分*/
        List<StayIntegral>  stayIntegralList = useIntegralMapper.listStayIntegral(stayIntegral);
        String msg = "";
        for(StayIntegral si : stayIntegralList ){
            try {
                msg = msg + useIntegralService.integralStayToAlready(si);
            }catch (Exception e){
                e.printStackTrace();
            }
        }
        logger.info(msg);
		/*增加入账记录*/
        return true;
    }

    @Override
    @Transactional
    public String integralStayToAlready(StayIntegral si) {
        String msg = "";
        /*增加入账积分，累计积分，减去待入账积分*/
        Member member = memberMapper.getMemberByUserOpenId(si.getUserOpenId());
        Member mem = new Member();
        mem.setUserOpenid(si.getUserOpenId());
        mem.setUserSurplusIntegral(member.getUserSurplusIntegral() + si.getStayNumber());
        mem.setUserIntegral(member.getUserIntegral() + si.getStayNumber());
        mem.setUserStayIntegral(member.getUserStayIntegral() - si.getStayNumber());
        Integer flag = memberMapper.updateMemberByUserId(mem);
        if (flag < 1) {
            logger.info("== 修改积分失败-->记录id："+ si.getStayId());
            throw new RuntimeException("修改积分失败");
        }

            /*添加入账日志*/
        UseIntegral useIntegral = new UseIntegral();
        useIntegral.setUserOpenId(si.getUserOpenId());
        useIntegral.setIntegralNumber(si.getStayNumber());
        useIntegral.setStayId(si.getStayId());
        useIntegral.setIntegralBeforeNumber(member.getUserSurplusIntegral()); //变动前
        useIntegral.setIntegralEndNumber(mem.getUserSurplusIntegral()); //变动后
        useIntegral.setIntegralType(1); //入账
        useIntegral.setConfigId(si.getConfigId());
        //useIntegral.setIntegralRemarks("由待入账变更为已入账");
        flag = useIntegralMapper.addUseIntegral(useIntegral);
        if (flag < 1) {
            logger.info("== 添加入账日志失败-->记录id："+ si.getStayId() );
            throw new RuntimeException("添加入账日志失败");
        }

            /*删除日志*/
        UseIntegral ui = new UseIntegral();
        ui.setUserOpenId(si.getUserOpenId());
        ui.setStayId(si.getStayId());
        ui.setIntegralType(3);
        flag = useIntegralMapper.delUseIntegral(ui);
        if (flag < 1) {
            logger.info("== 删除待入账日志失败-->记录id："+ si.getStayId() );
            msg += "== 删除待入账日志失败-->记录id："+ si.getStayId();
            //throw new RuntimeException("删除待入账日志失败");
        }

            /*再将待入账信息改为已入账状态*/
        StayIntegral stayInte =  new StayIntegral();
        stayInte.setStayId(si.getStayId());
        stayInte.setStayStatus(2);
        flag = useIntegralMapper.updateStayIntegral(stayInte);
        if (flag < 1) {
            logger.info("== 修改待入账状态失败-->记录id："+ si.getStayId() );
            throw new RuntimeException("修改待入账状态失败");
        }
        return msg;
    }

    /**
     * 查询单条数据
     * @param  id
     * @return  integralConfig
     */
    @Override
    public  IntegralConfig  getIntegralConfigById(Integer  id){
        return  useIntegralMapper.getIntegralConfigById(id);
    }

    /**
     * 获取集合
     * @param  useIntegral
     * @return List
     */
    @Override
    public  List<UseIntegral>  getUseIntegralList(UseIntegral  useIntegral){
        return  useIntegralMapper.getUseIntegralList(useIntegral);
    }

    @Override
    @Transactional
    public Integer activityPointChange(Member member) {
        Integer number = 0;
        if(member == null){
            logger.info("==用户为空：");
            throw new RuntimeException("用户为空");
        }
        if(member.getUserSurplusIntegral() == null){
            logger.info("==用户剩余积分为空");
            throw new RuntimeException("用户剩余积分为空");
        }
        if(member.getUserStayIntegral() == null){
            logger.info("==用户待入账积分为空");
            throw new RuntimeException("用户待入账积分为空");
        }
        if(member.getUserIntegral() == null){
            logger.info("==用户总积分为空");
            throw new RuntimeException("用户总积分为空");
        }
        logger.info("====用户OPENID："+member.getUserOpenid()+"=====积分变更开始=========");

        //待入账，查询条件  1
        //增加待入账，逐条增加，名称
        //获取待入账集合总金额
        StayIntegral stayIntegral = new StayIntegral();
        stayIntegral.setUserOpenId(member.getUserOpenid());
        stayIntegral.setStayStatus(1);
        List<StayIntegral> stayIntegralList = useIntegralMapper.listStayIntegral(stayIntegral);

        //获取积分配置的id
        ShopSystemRule renewRule =  systemService.selectOneShopRuleById(262);
        IntegralConfig ic = new IntegralConfig();
        ic.setIntegralConfigId(Integer.valueOf(renewRule.getRuleDesc()));
        List<IntegralConfig> configList = useIntegralMapper.listIntegralConfig(ic);
        ic = configList.get(0);

        //所有待入账的总和
        Integer stayInter = 0;
        if(stayIntegralList!=null && stayIntegralList.size()>0){
            for (StayIntegral si:stayIntegralList) {
                Double num = si.getStayNumber() * 0.1;
                stayInter += num.intValue();
                if(num.intValue() > 0){
                    StayIntegral newSi = new StayIntegral();
                    newSi.setUserOpenId(member.getUserOpenid());
                    newSi.setConfigId(ic.getIntegralConfigId());
                    newSi.setStayNumber(num.intValue());
                    newSi.setStayStatus(1);
                    newSi.setStayRecordedTime(si.getStayRecordedTime());
                    newSi.setStayStatus(1);
                    Integer fl = memberMapper.insertStayIntegral(newSi);
                    if (fl < 1) {
                        logger.info("==增加待入账失败，原待入账ID：" + si.getStayId());
                        throw new RuntimeException("增加待入账失败");
                    } else {
                        //添加待入账积分日志
                        UseIntegral useIntegral = new UseIntegral();
                        useIntegral.setConfigId(Integer.valueOf(renewRule.getRuleDesc()));
                        useIntegral.setUserOpenId(member.getUserOpenid());
                        useIntegral.setIntegralType(3);
                        useIntegral.setStayId(newSi.getStayId());
                        useIntegral.setIntegralNumber(num.intValue());
                        useIntegral.setIntegralBeforeNumber(0);
                        useIntegral.setIntegralEndNumber(0);
                        useIntegral.setIntegralRemarks(ic.getIntegralConfigName());
                        //添加积分获取日志信息
                        if (useIntegralMapper.addUseIntegral(useIntegral) < 1) {
                            logger.info("==添加待入账的积分日志失败，原待入账ID：" + si.getStayId());
                            throw new RuntimeException("添加待入账的积分日志失败");
                        }
                    }
                }
            }
        }

        //增加日志表，增加（剩余积分*0.1）的记录
        //添加日志
        Integer surplusIntegral = 0;
        Double userSurplusIntegral = member.getUserSurplusIntegral()*0.1;
        if( userSurplusIntegral.intValue() > 0){
            //需要直接加的积分
            surplusIntegral = userSurplusIntegral.intValue();
            UseIntegral useIntegral = new UseIntegral();
            useIntegral.setConfigId(ic.getIntegralConfigId());
            useIntegral.setUserOpenId(member.getUserOpenid());
            useIntegral.setIntegralType(1);
            useIntegral.setIntegralNumber(surplusIntegral);
            useIntegral.setIntegralBeforeNumber(member.getUserSurplusIntegral());
            useIntegral.setIntegralEndNumber(member.getUserSurplusIntegral() + surplusIntegral);
            useIntegral.setIntegralRemarks(ic.getIntegralConfigName());
            //添加积分获取日志信息
            if(useIntegralMapper.addUseIntegral(useIntegral) < 1){
                logger.info("==添加积分日志失败，用户openId：" + member.getUserOpenid());
                throw new RuntimeException("添加积分日志失败");
            }
        }

        //修改用户表
        //剩余积分=剩余积分+剩余积分*0.1
        //总积分=总积分+剩余积分*0.1
        //待入账=待入账+待入账集合总金额
        Member mem = new Member();
        mem.setUserId(member.getUserId());
        mem.setUserOpenid(member.getUserOpenid());
        if(surplusIntegral > 0){
            mem.setUserSurplusIntegral(member.getUserSurplusIntegral()+surplusIntegral);   //剩余积分
            mem.setUserIntegral(member.getUserIntegral()+surplusIntegral); //总积分 成长值
        }
        if(stayInter > 0){
            mem.setUserStayIntegral(member.getUserStayIntegral() + stayInter); //待入账积分
        }
        mem.setUserIsAc(1);
        Integer flag = memberMapper.update(mem);
        if(flag < 1){
            logger.info("==用户添加积分失败，用户openId：" + member.getUserOpenid());
            throw new RuntimeException("用户添加积分失败");
        }
        logger.info("====用户OPENID："+member.getUserOpenid()+"=====积分变更结束=========");
        return stayInter+surplusIntegral;
    }


}
