package com.iamberry.wechat.handles.coupon;

import java.util.*;

import javax.servlet.http.HttpServletRequest;

import com.iamberry.wechat.core.entity.activity.Activity;
import com.iamberry.wechat.core.entity.apparatus.Apparatus;
import com.iamberry.wechat.face.activity.ActivityService;
import com.iamberry.wechat.face.apparatus.ApparatusService;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import com.iamberry.wechat.core.entity.PageBean;
import com.iamberry.wechat.core.entity.ResultMsg;
import com.iamberry.wechat.core.entity.WechatUtils;
import com.iamberry.wechat.core.entity.coupon.CouponItem;
import com.iamberry.wechat.core.entity.coupon.CouponItemDto;
import com.iamberry.wechat.core.entity.coupon.CouponType;
import com.iamberry.wechat.core.entity.member.Member;
import com.iamberry.wechat.face.admin.SystemService;
import com.iamberry.wechat.face.coupon.CouponItemService;
import com.iamberry.wechat.face.coupon.CouponTypeService;
import com.iamberry.wechat.face.member.MemberService;
import com.iamberry.wechat.tools.DateTimeUtil;
import com.iamberry.wechat.tools.NameUtils;
import com.iamberry.wechat.tools.ResultInfo;

/**
 * 优惠券类型 前台接口 2016年7月6日
 * @author 穆再兴
 */
@Controller
@RequestMapping("/wechat/coupon")
public class CouponTypeHandler {
	@Autowired
	private CouponTypeService couponTypeService;
	@Autowired
	private CouponItemService couponItemService;
	@Autowired
	private MemberService memberService;
	@Autowired
	private SystemService systemService;
	@Autowired
	private ApparatusService apparatusService;
	@Autowired
	private ActivityService activityService;

	private static Logger logger = LoggerFactory.getLogger(CouponTypeHandler.class);
	/**
	 * 领取优惠券的锁
	 */
	private Object lock = new Object();

	/**
	 * 分页查询优惠券类型列表<当前用户可领取的> 2016年7月6日
	 * 
	 * @param pageSize
	 * @param pageNO
	 * @return
	 */
	@RequestMapping("/couponTypeList")
	@ResponseBody
	public ResultMsg getCouponTypeList(
			HttpServletRequest req,
			@RequestParam(value = "pageSize", defaultValue = "6", required = false) Integer pageSize,
			@RequestParam(value = "pageNO", defaultValue = "1", required = false) Integer pageNO) {
		ResultMsg rm = new ResultMsg();
		List<CouponType> typeList = new ArrayList<CouponType>();
		Map<String, Object> map = new HashMap<String, Object>();

		// 去掉已经领取过的
		CouponItemDto couponItemDto = new CouponItemDto();

		Member member = WechatUtils.getUserBySession(req);
		member = memberService.getMemberByUserOpenId(member.getUserOpenid());

		String typeIdStr = req.getParameter("typeId");
		logger.info("----------typeIdStr-----------" + typeIdStr);
		if (typeIdStr.indexOf("?") > -1) {
			typeIdStr = StringUtils.split(typeIdStr, "?")[0];
		}
		int couponTypeId = Integer.parseInt(typeIdStr);

		// 如果当前用户来自金牌会员，并且优惠券的ID为400元，那么屏蔽
		int templateId = systemService.selectOneShopRuleById(114).getRuleNum()
				.intValue();
		if (member.getTemplateId() != null && member.getTemplateId() == templateId) {
			map.put("typeList", typeList);
			rm.setData(map);
			rm.setStatus(true);
			rm.setResultCode(ResultInfo.SUCCESSCODE);
			rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
			return rm;
		}

		CouponType couponType = couponTypeService
				.getCouponTypeById(couponTypeId);
		typeList.add(couponType);

		couponItemDto.setUseropenid(member.getUserOpenid());
		List<CouponItemDto> itemList = couponItemService
				.getCouponItemDtoList(couponItemDto);
		Iterator<CouponType> it = typeList.iterator();
		while (it.hasNext()) {
			CouponType cType = (CouponType) it.next();
			Date now = new Date();
			// 券已过期
			if (cType.getCouponEndDate() != null
					&& cType.getCouponEndDate().before(now)) {
				it.remove();
				continue;
			}
			// 券已领完
			if (cType.getCouponRemainingNum() != null
					&& cType.getCouponRemainingNum().intValue() < 1) {
				it.remove();
				continue;
			}
			// 券使用条件为必须关注时，用户没关注则返回
			if (cType.getCouponIsConcern() != null
					&& cType.getCouponIsConcern().intValue() == 1
					&& member.getUserStatus() != null
					&& member.getUserStatus().intValue() != 2) {
				it.remove();
				continue;
			}
			//如果有来源限制，则不在该来源范围内的不能领取优惠券
			if (cType.getCouponIsSource() == 1 && StringUtils.isNotEmpty(cType.getCouponSourceName())) {
				// 当前路径，相对于应用路径，不包括参数
				String referer = req.getHeader("referer");
				if (referer.indexOf(cType.getCouponSourceName()) < 0) {
					it.remove();
					continue;
				}
			}


			// 当前用户已领取且时间为一个月以内
			for (CouponItemDto cItem : itemList) {
				if (cType.getCouponId() != null
						&& cItem.getCouponId() != null
						&& cType.getCouponId().intValue() == cItem
								.getCouponId().intValue()) {
					Date date = new Date();
					long beginTime = cItem.getCouponReceiveDate().getTime();
					long endTime2 = date.getTime();
					long betweenDays = (long)((endTime2 - beginTime) / (1000 * 60 * 60 *24));
					if (betweenDays < 30) {
						it.remove();
					}
					break;
				}
			}
		}

		map.put("typeList", typeList);
		rm.setData(map);
		rm.setStatus(true);
		rm.setResultCode(ResultInfo.SUCCESSCODE);
		rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
		return rm;
	}

	/**
	 * 用户领取优惠券接口 2016年7月6日
	 * @author 穆再兴
	 * @return
	 */
	@RequestMapping("/getCoupon")
	@ResponseBody
	public ResultMsg getCoupon(HttpServletRequest req,
			@RequestParam(value = "couponId", required = false) Integer couponId) {
		ResultMsg rm = new ResultMsg();
		if (couponId == null) {
			rm.setStatus(false);
			rm.setResultCode(ResultInfo.ERRORCODE);
			rm.setMessage(NameUtils.getConfig("ERRORINFO"));
		}

		Member member = WechatUtils.getUserBySession(req);
		member = memberService.getMemberByUserOpenId(member.getUserOpenid());
		synchronized (lock) {
			CouponType ct = couponTypeService.getCouponTypeById(couponId);
			rm = checkCoupon(member, ct);
			if (rm.isStatus()) {
				rm = getCouponItem(member, ct);
				return rm;
			} else {
				return rm;
			}
		}
	}

	/**
	 * 校验某用户是否符合领取优惠券条件
	 * 
	 * @param member
	 * @param couponType
	 * @return
	 */
	private ResultMsg checkCoupon(Member member, CouponType couponType) {
		ResultMsg rm = new ResultMsg();
		rm.setStatus(false);
		if (member == null || couponType == null) {
			rm.setMessage(NameUtils.getConfig("ERRORINFO"));
			return rm;
		}
		Date now = new Date();
		// 券已过期
		if (couponType.getCouponEndDate() != null
				&& couponType.getCouponEndDate().before(now)) {
			rm.setMessage("本次优惠券领取已结束!");
			return rm;
		}
		// 券已领完
		if (couponType.getCouponRemainingNum() < 1) {
			rm.setMessage("本次优惠券已被抢完,欢迎下次再来~");
			return rm;
		}
		// 券使用条件为必须关注时，用户没关注则返回
		if (couponType.getCouponIsConcern() == 1
				&& member.getUserStatus() != null
				&& member.getUserStatus().intValue() != 2) {
			rm.setMessage("请先关注公众号!");
			return rm;
		}
		// 已经领取过
		CouponItemDto couponItemDto = new CouponItemDto();
		couponItemDto.setCouponId(couponType.getCouponId());
		couponItemDto.setUseropenid(member.getUserOpenid());
		List<CouponItemDto> list = couponItemService
				.getCouponItemDtoList(couponItemDto);
		if (list != null && list.size() >= couponType.getCouponGetLimit()) {
			rm.setMessage("该优惠券您已全部领取,请勿重复领取!");
			return rm;
		}
		// 待加条件：是否必须购买 消费总金额要求（满足这个条件才能领券）
		rm.setStatus(true);
		rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
		return rm;
	}

	/**
	 * 领取某类型的优惠券 总数量减少 优惠券详情表插入数据
	 * 
	 * @param member
	 * @param couponType
	 * @return
	 */
	private ResultMsg getCouponItem(Member member, CouponType couponType) {
		ResultMsg rm = new ResultMsg();
		rm.setStatus(false);
		rm.setMessage(NameUtils.getConfig("ERRORINFO"));
		// 减少总数
		int i = couponTypeService.updateCouponTypeForItem(couponType
				.getCouponId());

		// 增加单张优惠券
		CouponItem couponItem = new CouponItem();
		couponItem.setCouponItemUseropenid(member.getUserOpenid());
		couponItem.setCouponId(couponType.getCouponId());
		couponItem.setCouponUseStatus(1); // 使用状态:未使用
		Date endDate = DateTimeUtil.addHour(DateTimeUtil.now(),
				couponType.getCouponLimitHours()); // 券的过期时间
		if (endDate.before(couponType.getCouponEndDate())) { // 券的过期时间早于此类型券的截止时间则取券的过期时间
			couponItem.setCouponUseEndDate(endDate);
		} else { // 券的过期时间晚于此类型券的截止时间则取此类型券的截止时间
			couponItem.setCouponUseEndDate(couponType.getCouponEndDate());
		}
		Integer j = couponItemService.insertCouponItem(couponItem);

		if (i > 0 && j != null && j.intValue() > 0) {
			rm.setStatus(true);
			rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
			rm.setData(couponItem);
		}
		return rm;
	}

	/**
	 * 当前用户各种状态优惠券列表 2016年7月7日
	 * 
	 * @param req
	 * @param pageSize
	 * @param pageNO
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/couponItemList")
	public ResultMsg getCouponItemList(
			HttpServletRequest req,
			@RequestParam(value = "pageSize", defaultValue = "6", required = false) Integer pageSize,
			@RequestParam(value = "pageNO", defaultValue = "1", required = false) Integer pageNO) {
		ResultMsg rm = new ResultMsg();
		String useStatus = req.getParameter("useStatus");
		if (StringUtils.isEmpty(useStatus)) {
			useStatus = "-1";
		}
		String openid = "";
		Member member = WechatUtils.getUserBySession(req);
		openid = member.getUserOpenid();
		CouponItemDto cDto = new CouponItemDto();
		cDto.setUseropenid(openid);
//		if ("1".equals(useStatus)) { // 未使用的优惠券
//			cDto.setCouponUseStatus(Integer.parseInt(useStatus));
//			cDto.setBeginDate(new Date());
//		} else if ("2".equals(useStatus)) { // 已使用的优惠券
//			cDto.setCouponUseStatus(Integer.parseInt(useStatus));
//			cDto.setCouponReduce(7); // 加上了订单是待支付 即couponUseStatus是7的优惠券
//		} else if ("3".equals(useStatus)) { // 已过期的优惠券
//			cDto.setEndDate(new Date());
//			cDto.setCouponItemRemark("4"); // 需去掉已经使用的优惠券
//		}
		cDto.setPage(new PageBean());
		cDto.getPage().setPageSize(pageSize);
		cDto.getPage().setPageNumber(pageNO);
		cDto.getPage().setRecordBegin((pageNO-1)*pageSize);
		cDto.setCouponUseStatus(1);//只展示未使用的
		cDto.setBeginDate(new Date()); //大于当前时间
		List<CouponItemDto> list = couponItemService.getCouponItemDtoList(cDto);

		Date now = new Date();
		for (CouponItemDto itemDto : list) { // 为了在全部优惠券页面区分已过期的优惠券，使之不能使用
			itemDto.setCouponItemRemark(ResultInfo.COUPONITEMSTATUS_NORMAL);
			if (itemDto.getCouponUseEndDate() != null
					&& itemDto.getCouponUseEndDate().before(now)) {
				itemDto.setCouponItemRemark(ResultInfo.COUPONITEMSTATUS_PASSED);
			}
		}
		Map<String, Object> map = new HashMap<String, Object>();
		map.put("itemList", list);
		rm.setData(map);
		rm.setStatus(true);
		rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
		return rm;
	}

	/**
	 * 当前用户可领取的优惠券数 2016年7月11日
	 * 
	 * @return
	 */
	@RequestMapping("/getNewCouponType")
	@ResponseBody
	public ResultMsg getCouponTypeCount(HttpServletRequest req) {
		ResultMsg rm = new ResultMsg();
		CouponType ct = new CouponType();
		ct.setPage(new PageBean());
		List<CouponType> typeList = couponTypeService.getCouponTypeList(ct);
		Integer count = couponTypeService.getCouponTypeCount();

		// 去掉已经领取过的
		CouponItemDto couponItemDto = new CouponItemDto();

		Member member = WechatUtils.getUserBySession(req);
		member = memberService.getMemberByUserOpenId(member.getUserOpenid());
		couponItemDto.setUseropenid(member.getUserOpenid());
		List<CouponItemDto> itemList = couponItemService
				.getCouponItemDtoList(couponItemDto);
		Iterator<CouponType> it = typeList.iterator();
		while (it.hasNext()) {
			CouponType cType = (CouponType) it.next();
			Date now = new Date();
			// 券已过期
			if (cType.getCouponEndDate() != null
					&& cType.getCouponEndDate().before(now)) {
				it.remove();
				count--;
				continue;
			}
			// 券已领完
			if (cType.getCouponRemainingNum() < 1) {
				it.remove();
				count--;
				continue;
			}
			// 券使用条件为必须关注时，用户没关注则返回
			if (cType.getCouponIsConcern() == 1
					&& member.getUserStatus() != null
					&& member.getUserStatus().intValue() != 2) {
				it.remove();
				count--;
				continue;
			}
			// 当前用户已领取
			for (CouponItemDto cItem : itemList) {
				if (cType.getCouponId() == cItem.getCouponId()) {
					it.remove();
					count--;
					break;
				}
			}
		}

		rm.setData(count);
		rm.setStatus(true);
		rm.setResultCode(ResultInfo.SUCCESSCODE);
		rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
		return rm;
	}

	/**
	 * 分页查询优惠券类型列表<当前用户可领取的> 2016年7月6日
	 * 
	 * @param req
	 * @return
	 */
	@RequestMapping("/get_coupon_type")
	@ResponseBody
	public ResultMsg getCouponTypeById(HttpServletRequest req) {
		ResultMsg rm = new ResultMsg();

		List<CouponType> typeList = new ArrayList<CouponType>();
		Map<String, Object> map = new HashMap<String, Object>();

		// 去掉已经领取过的
		CouponItemDto couponItemDto = new CouponItemDto();

		Member member = WechatUtils.getUserBySession(req);
		member = memberService.getMemberByUserOpenId(member.getUserOpenid());

		// 如果该用户直接上级是门店或是母婴店，则不能领取优惠券
		if (member.getUserResType() == 3) {
			map.put("typeList", typeList);
			rm.setData(map);
			rm.setStatus(true);
			rm.setResultCode(ResultInfo.SUCCESSCODE);
			rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
			return rm;
		}

		int couponTypeId = Integer.parseInt(req.getParameter("typeId"));

		CouponType couponType = couponTypeService
				.getCouponTypeById(couponTypeId);
		typeList.add(couponType);

		couponItemDto.setUseropenid(member.getUserOpenid());
		List<CouponItemDto> itemList = couponItemService
				.getCouponItemDtoList(couponItemDto);
		Iterator<CouponType> it = typeList.iterator();
		while (it.hasNext()) {
			CouponType cType = (CouponType) it.next();
			Date now = new Date();
			// 券已过期
			if (cType.getCouponEndDate() != null
					&& cType.getCouponEndDate().before(now)) {
				it.remove();
				continue;
			}
			// 券已领完
			if (cType.getCouponRemainingNum() != null
					&& cType.getCouponRemainingNum().intValue() < 1) {
				it.remove();
				continue;
			}
			// 券使用条件为必须关注时，用户没关注则返回
			if (cType.getCouponIsConcern() != null
					&& cType.getCouponIsConcern().intValue() == 1
					&& member.getUserStatus() != null
					&& member.getUserStatus().intValue() != 2) {
				it.remove();
				continue;
			}
			// 当前用户已领取
			for (CouponItemDto cItem : itemList) {
				if (cType.getCouponId() != null
						&& cItem.getCouponId() != null
						&& cType.getCouponId().intValue() == cItem
								.getCouponId().intValue()) {
					it.remove();
					break;
				}
			}
		}

		map.put("typeList", typeList);
		rm.setData(map);
		rm.setStatus(true);
		rm.setResultCode(ResultInfo.SUCCESSCODE);
		rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
		return rm;
	}

	/**
	 * 校验当前用户是否符合使用优惠券条件
	 * 
	 * @return
	 */
	@RequestMapping("/checkCurrentPreferential")
	@ResponseBody
	private ResultMsg checkCurrentPreferential(HttpServletRequest req) {
		ResultMsg rm = new ResultMsg();
		Member member = WechatUtils.getUserBySession(req);
		rm.setStatus(false);
		rm.setMessage("当前用户非金牌会员下线");
		// 查询金牌会员模板id
		int templateId = systemService.selectOneShopRuleById(114).getRuleNum()
				.intValue();
		// 查询用户信息
		Member user = memberService.getMemberByUserOpenId(member
				.getUserOpenid());
		if (user == null) {
			rm.setMessage(ResultInfo.loginOutError);
			rm.setStatus(false);
			return rm;
		}
		// 判断是否为金牌会员下线，如果是，则以优惠价显示，如果不是则按原价显示
		if (user.getUserDealers() != null && user.getTemplateId() != null
				&& templateId == user.getTemplateId().intValue()
				&& user.getUserResType() == 3) {
			rm.setMessage(NameUtils.getConfig("SUCCESSINFO"));
			rm.setStatus(true);
		}
		return rm;
	}

	/**
	 * 获取用户是否已领取优惠券 -20000
	 * @param request
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/getIsReceive")
	public ResultMsg getIsReceive(HttpServletRequest request) {
		ResultMsg resultMsg = new ResultMsg();
		Member memberInfo = WechatUtils.getUserBySession(request);

		memberInfo = memberService.getMemberByUserOpenId(memberInfo.getUserOpenid());

//		Integer msg = couponItemService.getIsReceive(memberInfo.getUserOpenid());
		CouponItemDto couponItemDto = new CouponItemDto();
		couponItemDto.setUseropenid(memberInfo.getUserOpenid());
		couponItemDto.setCouponIsNewPeople(1);
		List<CouponItemDto> couponItemDtoList = couponItemService.getCouponItemDtoList(couponItemDto);

		CouponItemDto cidLips = new CouponItemDto();
		cidLips.setUseropenid(memberInfo.getUserOpenid());
		cidLips.setCouponId(20004);
		List<CouponItemDto> cidLipsList = couponItemService.getCouponItemDtoList(cidLips);

		Activity activity = new Activity();
		activity.setUserOpenId(memberInfo.getUserOpenid());
		List<Activity> activityList = activityService.getActivityList(activity);

		boolean flag = true;
		if (couponItemDtoList != null && couponItemDtoList.size() > 0) {
			if(couponItemDtoList.size() > 1){
				flag = false;
			}else{
				if (activityList != null && activityList.size() > 0) {
					Activity ac = activityList.get(0);
					CouponItemDto ci = couponItemDtoList.get(0);
					if(ci.getCouponItemId().equals(ac.getActivityCoupon())){
						flag = true;
					}else{
						flag = false;
					}
				}else{
					flag = false;
				}
			}
		}else{	//未领取优惠券
			flag = true;
		}
		if(cidLipsList != null && cidLipsList.size() > 0 ){
			flag = false;
		}
		if (!flag) {
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("已领取优惠券");
			return resultMsg;
		}else{
			/*未领取优惠券*/
			if(memberInfo != null && memberInfo.getUserIdentity() == 1){
				resultMsg.setResultCode(ResultInfo.SUCCESSCODE);
				resultMsg.setStatus(true);
				return resultMsg;
			}else{
				resultMsg.setResultCode("505");
				resultMsg.setStatus(false);
				resultMsg.setMessage("需要成为会员才能领取该优惠券");
				return resultMsg;
			}
		}
	}

	/**
	 * 点击领取新人优惠券（为当前用户新增一条优惠券）20000
	 * @param request
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/addAewPeople")
	public ResultMsg addAewPeople(HttpServletRequest request){
		ResultMsg resultMsg = new ResultMsg();
		Member memberInfo = WechatUtils.getUserBySession(request);
		memberInfo = memberService.getMemberByUserOpenId(memberInfo.getUserOpenid());
//		CouponType couponType = new CouponType();
//		couponType.setCouponIsNewPeople(1);
//		couponType.setPage(new PageBean());
//		List<CouponType> couponTypeList = couponTypeService.getCouponTypeList(couponType);
//		if(couponTypeList == null || couponTypeList.size() < 1){
//			resultMsg.setResultCode(ResultInfo.ERRORCODE);
//			resultMsg.setStatus(false);
//			return resultMsg;
//		}

//		Integer msg = couponItemService.getIsReceive(memberInfo.getUserOpenid());

		CouponItemDto couponItemDto = new CouponItemDto();
		couponItemDto.setUseropenid(memberInfo.getUserOpenid());
		couponItemDto.setCouponIsNewPeople(1);
		List<CouponItemDto> couponItemDtoList = couponItemService.getCouponItemDtoList(couponItemDto);

		CouponItemDto cidLips = new CouponItemDto();
		cidLips.setUseropenid(memberInfo.getUserOpenid());
		cidLips.setCouponId(20004);
		List<CouponItemDto> cidLipsList = couponItemService.getCouponItemDtoList(cidLips);

		Activity activity = new Activity();
		activity.setUserOpenId(memberInfo.getUserOpenid());
		List<Activity> activityList = activityService.getActivityList(activity);

		boolean isNewLIps = false;
		Apparatus apparatus = new Apparatus();
		apparatus.setUserOpenid(memberInfo.getUserOpenid());
		List<Apparatus> apparatusList = apparatusService.listApparatusPage(apparatus);
		for (Apparatus app : apparatusList) {
			if(app != null && app.getColorId() != null){
				if(app.getColorId() == 100 || app.getColorId() == 101 || app.getColorId() == 102){
					isNewLIps = true;
				}
			}
		}

		boolean flag = true;
		if (couponItemDtoList != null && couponItemDtoList.size() > 0) {
			if(couponItemDtoList.size() > 1){
				flag = false;
			}else{
				if (activityList != null && activityList.size() > 0) {
					Activity ac = activityList.get(0);
					CouponItemDto ci = couponItemDtoList.get(0);
					if(ac.getActivityCoupon().equals(ci.getCouponItemId()) ){
						flag = true;
					}else{
						flag = false;
					}
				}else{
					flag = false;
				}
			}
		}else{	//未领取优惠券
			flag = true;
		}

		if(cidLipsList != null && cidLipsList.size() > 0 ){
			flag = false;
		}

		Integer fl = 0;

		if (!flag) {
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("领取失败，该用户已领取过优惠券");
			return resultMsg;
		}else{
			if(memberInfo.getUserIdentity() != 1){
				resultMsg.setResultCode("505");
				resultMsg.setStatus(false);
				resultMsg.setMessage("需要成为会员才能领取");
				return resultMsg;
			}

			if(isNewLIps){
				CouponItem ci = new CouponItem();
				ci.setCouponId(20001);
				Calendar cdi = Calendar.getInstance();
				cdi.add(Calendar.DATE,60);
				ci.setCouponUseEndDate(cdi.getTime());//领取后一年有效
				ci.setCouponReceiveDate(new Date());
				ci.setCouponItemUseropenid(memberInfo.getUserOpenid());
				ci.setCouponUseStatus(1);
				ci.setCouponIsDonation(2);
				ci.setCouponItemRemark("399轻奢款牙刷60元优惠券/仅限微商城使用");
				fl = couponItemService.insertCouponItem(ci);

				CouponItem couponItem = new CouponItem();
				couponItem.setCouponId(20004);
				Calendar calendar = Calendar.getInstance();
				calendar.add(Calendar.YEAR,1);
				couponItem.setCouponUseEndDate(calendar.getTime());//领取后一年有效
				couponItem.setCouponReceiveDate(new Date());
				couponItem.setCouponItemUseropenid(memberInfo.getUserOpenid());
				couponItem.setCouponUseStatus(1);
				couponItem.setCouponIsDonation(2);
				couponItem.setCouponItemRemark("Lips刷头抵扣券（仅限Lips单支刷头）");
				fl = couponItemService.insertCouponItem(couponItem);
				if(fl < 1){
					resultMsg.setResultCode(ResultInfo.ERRORCODE);
					resultMsg.setMessage("领取出错");
					resultMsg.setStatus(false);
					return resultMsg;
				}
			}else{
				CouponItem couponItem = new CouponItem();
				couponItem.setCouponId(20000);
				Calendar calendar = Calendar.getInstance();
				calendar.add(Calendar.YEAR,1);
				couponItem.setCouponUseEndDate(calendar.getTime());//领取后一年有效
				couponItem.setCouponReceiveDate(new Date());
				couponItem.setCouponItemUseropenid(memberInfo.getUserOpenid());
				couponItem.setCouponUseStatus(1);
				couponItem.setCouponIsDonation(2);
				couponItem.setCouponItemRemark("新人优惠券");
				fl = couponItemService.insertCouponItem(couponItem);
				if(fl < 1){
					resultMsg.setResultCode(ResultInfo.ERRORCODE);
					resultMsg.setMessage("领取出错");
					resultMsg.setStatus(false);
					return resultMsg;
				}
			}

			if(fl > 0){
				resultMsg.setResultCode(ResultInfo.SUCCESSCODE);
				resultMsg.setStatus(true);
			}else{
				resultMsg.setResultCode(ResultInfo.ERRORCODE);
				resultMsg.setMessage("领取出错");
				resultMsg.setStatus(false);
				return resultMsg;
			}
		}
		return resultMsg;
	}


	/**
	 * 获取用户是否已领取优惠券 30000
	 * @param request
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/isReceive")
	public ResultMsg isReceive(HttpServletRequest request,Integer couponId){
		ResultMsg resultMsg = new ResultMsg();
		Member memberInfo = WechatUtils.getUserBySession(request);
		CouponItem couponItem = new CouponItem();
		couponItem.setCouponItemUseropenid(memberInfo.getUserOpenid());
		couponItem.setCouponId(couponId);
		Integer msg = couponItemService.isReceive(couponItem);
		if(couponId == null || "".equals(couponId)){
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("未查询到到优惠券");
			return resultMsg;
		}

		/*获取优惠券类型*/
		CouponType couponType = couponTypeService.getCouponTypeById(couponId);

		if(couponType.getCouponEndDate().before(new Date())){   //couponType.getCouponEndDate 小于 new Date()
			resultMsg.setResultCode("501");
			resultMsg.setStatus(false);
			resultMsg.setMessage("活动已过期！");
			return resultMsg;
		}

		if(couponType != null &&  msg < couponType.getCouponGetLimit()){
			resultMsg.setResultCode(ResultInfo.SUCCESSCODE);
			resultMsg.setStatus(true);
		}else{
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("无法领取该优惠券");
			return resultMsg;
		}
		return resultMsg;
	}

	/**
	 * 领取优惠券 30000
	 * @param request
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/receive_coupon")
	public ResultMsg receiveCoupon(HttpServletRequest request,Integer couponId){
		ResultMsg resultMsg = new ResultMsg();
		Member memberInfo = WechatUtils.getUserBySession(request);
		if(couponId == null || "".equals(couponId)){
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("未查询到到优惠券");
			return resultMsg;
		}
		CouponItem couponItem = new CouponItem();
		couponItem.setCouponItemUseropenid(memberInfo.getUserOpenid());
		couponItem.setCouponId(couponId);
		Integer msg = couponItemService.isReceive(couponItem);
		/*获取优惠券类型*/
		CouponType couponType = couponTypeService.getCouponTypeById(couponId);

		if(couponType.getCouponEndDate().before(new Date())){   //couponType.getCouponEndDate < new Date()
			resultMsg.setResultCode("501");
			resultMsg.setStatus(false);
			resultMsg.setMessage("活动已过期！");
			return resultMsg;
		}

		/* 比对每个人限领的张数 */
		if(couponType != null &&  msg < couponType.getCouponGetLimit()){
			CouponItem ci = new CouponItem();
			ci.setCouponId(couponType.getCouponId());
			Calendar calendar = Calendar.getInstance();
			calendar.add(Calendar.MONTH,1);
			ci.setCouponUseEndDate(calendar.getTime());//领取后一月有效
			ci.setCouponReceiveDate(new Date());
			ci.setCouponItemUseropenid(memberInfo.getUserOpenid());
			ci.setCouponUseStatus(1);
			ci.setCouponIsDonation(2);
			ci.setCouponItemRemark("100元现金券");
			if(couponItemService.insertCouponItem(ci) > 0){
				resultMsg.setResultCode(ResultInfo.SUCCESSCODE);
				resultMsg.setStatus(true);
			}else{
				resultMsg.setResultCode(ResultInfo.ERRORCODE);
				resultMsg.setStatus(false);
			}
		}else{
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("已领取过该优惠券了");
			return resultMsg;
		}
		return resultMsg;
	}


	/**
	 *  领取优惠券
	 * @param request
	 * @param couponId
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/re_coupon")
	public ResultMsg reCoupon(HttpServletRequest request,Integer couponId){
		ResultMsg resultMsg = new ResultMsg();
		Member memberInfo = WechatUtils.getUserBySession(request);
		memberInfo = memberService.getMemberByUserOpenId(memberInfo.getUserOpenid());
		if(couponId == null || "".equals(couponId)){
			resultMsg.setResultCode("500");
			resultMsg.setStatus(false);
			resultMsg.setMessage("未查询到到优惠券");
			return resultMsg;
		}
		/*获取优惠券类型*/
		CouponType couponType = couponTypeService.getCouponTypeById(couponId);
		if(couponType == null){
			resultMsg.setResultCode("500");
			resultMsg.setStatus(false);
			resultMsg.setMessage("未查询到到优惠券");
			return resultMsg;
		}

		if(memberInfo.getUserStatus() != 2){
			resultMsg.setResultCode("501");
			resultMsg.setStatus(false);
			resultMsg.setMessage("本优惠券仅限关注之后使用，请搜索微信公众号“soodo上朵”并关注。");
			return resultMsg;
		}

		Calendar c = Calendar.getInstance();//获取一个日历实例
		c.setTime(couponType.getCouponEndDate());	//coupon_end_date
		Date endDate = c.getTime();

		if(endDate.before(new Date())){   //endDate < new Date()  当前时间大于结束时间了，活动过期了
			resultMsg.setResultCode("502");
			resultMsg.setStatus(false);
			resultMsg.setMessage("活动已过期");
			return resultMsg;
		}

		CouponItem couponItem = new CouponItem();
		couponItem.setCouponItemUseropenid(memberInfo.getUserOpenid());
		couponItem.setCouponId(couponId);
		Integer msg = couponItemService.isReceive(couponItem);

		/* 比对每个人限领的张数 */
		if(msg < couponType.getCouponGetLimit()){
			CouponItem ci = new CouponItem();
			ci.setCouponId(couponType.getCouponId());

			if(couponType.getCouponIsUseEnd() == 2){
				Calendar calendar = Calendar.getInstance();
				calendar.add(Calendar.DATE,couponType.getCouponGetDays());	//增加X天
				ci.setCouponUseEndDate(calendar.getTime());
			}else{
				ci.setCouponUseEndDate(couponType.getCouponUseEndDate());
			}
			ci.setCouponReceiveDate(new Date());
			ci.setCouponItemUseropenid(memberInfo.getUserOpenid());
			ci.setCouponUseStatus(1);
			ci.setCouponIsDonation(2);
			ci.setCouponItemRemark(couponType.getCouponRemark());
			if(couponItemService.insertCouponItem(ci) > 0){
				resultMsg.setResultCode(ResultInfo.SUCCESSCODE);
				resultMsg.setMessage("恭喜您获得一张"+couponType.getCouponName());
				resultMsg.setStatus(true);
				try{
					couponTypeService.updateCouponTypeForItem(couponId);
				}catch (Exception e){
					e.printStackTrace();
				}
			}else{
				resultMsg.setResultCode(ResultInfo.ERRORCODE);
				resultMsg.setMessage("领取失败");
				resultMsg.setStatus(false);
			}
		}else{
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("每人限领"+  couponType.getCouponGetLimit() +"张");
			return resultMsg;
		}
		return resultMsg;
	}

	/**
	 *  领取优惠券
	 * @param request
	 * @param couponId
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/re_two_coupon")
	public ResultMsg reTwoCoupon(HttpServletRequest request,Integer couponId){
		ResultMsg resultMsg = new ResultMsg();
		Member memberInfo = WechatUtils.getUserBySession(request);
		memberInfo = memberService.getMemberByUserOpenId(memberInfo.getUserOpenid());
		if(couponId == null || "".equals(couponId)){
			resultMsg.setResultCode("500");
			resultMsg.setStatus(false);
			resultMsg.setMessage("未查询到到优惠券");
			return resultMsg;
		}
		/*获取优惠券类型*/
		CouponType couponType = couponTypeService.getCouponTypeById(couponId);
		if(couponType == null){
			resultMsg.setResultCode("500");
			resultMsg.setStatus(false);
			resultMsg.setMessage("未查询到到优惠券");
			return resultMsg;
		}

		if(memberInfo.getUserStatus() != 2){
			resultMsg.setResultCode("501");
			resultMsg.setStatus(false);
			resultMsg.setMessage("本优惠券仅限关注之后使用，请搜索微信公众号“soodo上朵”并关注。");
			return resultMsg;
		}

		CouponItem couponItem = new CouponItem();
		couponItem.setCouponItemUseropenid(memberInfo.getUserOpenid());
		couponItem.setCouponId(couponId);
		Integer msg = couponItemService.isReceive(couponItem);

		if(couponType.getCouponEndDate().before(new Date())){   //couponType.getCouponEndDate < new Date()
			resultMsg.setResultCode("501");
			resultMsg.setStatus(false);
			resultMsg.setMessage("活动已过期！");
			return resultMsg;
		}

		/* 比对每个人限领的张数 */
		if(msg < couponType.getCouponGetLimit()){
			CouponItem ci = new CouponItem();
			ci.setCouponId(couponType.getCouponId());

			Calendar calendar = Calendar.getInstance();
			calendar.setTime(new Date());
			calendar.add(Calendar.DAY_OF_MONTH, couponType.getCouponGetDays());	//couponGetDays
			calendar.set(Calendar.HOUR_OF_DAY, 23);//时
			calendar.set(Calendar.MINUTE, 59);//分
			calendar.set(Calendar.SECOND, 59);

			ci.setCouponUseEndDate(calendar.getTime());
			ci.setCouponReceiveDate(new Date());
			ci.setCouponItemUseropenid(memberInfo.getUserOpenid());
			ci.setCouponUseStatus(1);
			ci.setCouponIsDonation(2);
			ci.setCouponItemRemark(couponType.getCouponRemark());
			if(couponItemService.insertCouponItem(ci) > 0){
				resultMsg.setResultCode(ResultInfo.SUCCESSCODE);
				resultMsg.setStatus(true);
				try{
					couponTypeService.updateCouponTypeForItem(couponId);
				}catch (Exception e){
					e.printStackTrace();
				}
			}else{
				resultMsg.setResultCode(ResultInfo.ERRORCODE);
				resultMsg.setStatus(false);
			}
		}else{
			resultMsg.setResultCode(ResultInfo.ERRORCODE);
			resultMsg.setStatus(false);
			resultMsg.setMessage("每人限领"+  couponType.getCouponGetLimit() +"张");
			return resultMsg;
		}
		return resultMsg;
	}


}
